@@ -24,6 +24,8 @@ class CreateSpider:
         elif self.spider_type == 3:
             self.path_template_spider = self.path_template.joinpath('spider_cycle.tmpl')
         elif self.spider_type == 4:
+            if not spider_name.lower().endswith('jump'):
+                self.spider_name += '_jump'
             self.path_template_spider = self.path_template.joinpath('spider_jump.tmpl')
         else:
             self.path_template_spider = self.path_template.joinpath('spider_local.tmpl')
@@ -40,7 +42,7 @@ class CreateSpider:
         if not spider_dir:
             spider_dir = self.path
 
-        if self.spider_type != 4 and spider_dir.joinpath(self.spider_name.lower() + '.py').exists():
+        if spider_dir.joinpath(self.spider_name.lower() + '.py').exists():
             raise SpiderHasExistsError(f'{self.spider_name.lower()} 已存在！')
 
         with open(self.path_template_spider, 'r', encoding='utf-8') as f:
